@@ -2,16 +2,17 @@ from tornado.web import Application, RequestHandler
 
 
 class App(Application):
-    def __init__(self, log, app_handlers, app_settings):
+    def __init__(self, app_handlers, app_settings):
         handlers = app_handlers.get()
         settings = app_settings.get()
-        super().__init__(handlers=app_handlers.get(), **settings)
+        super().__init__(handlers=handlers, **settings)
 
 
 class AppHandlers:
-    def __init__(self):
+    def __init__(self, flags, log):
+        opts = dict(flags=flags, log=log)
         self._handlers = [
-            (r"/health", HealthHandler),
+            (r"/health", HealthHandler, opts),
         ]
 
     def get(self):
@@ -20,7 +21,7 @@ class AppHandlers:
 
 class AppSettings:
     def __init__(self, log, flags):
-        self._log = log
+        self._log = log.bind(is_request_log=True, is_app_log=False)
         self._settings = dict(debug=flags["debug"], log_function=self._log_function)
 
     def get(self):
@@ -37,13 +38,29 @@ class AppSettings:
         request_time = 1000.0 * handler.request.request_time()
 
         log_method(
-            handler._request_summary(),
+            handler._request_summary(),  # pylint: disable=protected-access
             req_status=handler.get_status(),
             req_time=request_time,
         )
 
 
-class HealthHandler(RequestHandler):
+class ExceptionHandler:
+    def log_exception(
+        self, exc_type, exc_info, trace_back
+    ):  # pylint: disable=unused-argument
+        if getattr(self, "_logger"):
+            self._logger.error(  # pylint: disable=no-member
+                "Request: Error", exc_info=exc_info, stack_info=True
+            )
+
+
+class HealthHandler(ExceptionHandler, RequestHandler):
+    def initialize(self, flags, log):  # pylint: disable=unused-argument
+        self._logger = log  # pylint: disable=attribute-defined-outside-init
+
+    def data_received(self, chunk):
+        pass
+
     def get(self):
         self.write({"healthy": True})
         self.flush()
